iita.
"print"(x, ...)iita, obtained from a call to the function iita.x is of required type, print.iita prints the set of implications.Uenlue, A. and Sargin, A. (2010) DAKS: An R package for data analysis methods in knowledge space theory. Journal of Statistical Software, 37(2), 1--31. URL http://www.jstatsoft.org/v37/i02/.
iita, the interface that provides the three (sample) inductive item tree analysis methods
under one umbrella. See also DAKS-package for general
information about this package.